..  _rethinkorm:

rethinkORM
==========

:mod:`rethinkModel` Module
--------------------------

.. autoclass:: rethinkORM.rethinkModel.RethinkModel
    :members: __init__, finishInit, __delitem__, __contains__, new, find, save, delete, __repr__, protectedItems, primaryKey, table, durability, non_atomic, upsert, create
    :undoc-members:

:mod:`rethinkCollection` Module
-------------------------------

.. autoclass:: rethinkORM.rethinkCollection.RethinkCollection
    :members: __init__, joinOn, joinOnAs, orderBy, fetch
    :undoc-members:

Subpackages
-----------

.. toctree::

    rethinkORM.tests
